#[non_exhaustive]pub enum ParameterFormat {
Unspecified,
Unformatted,
Yaml,
Json,
UnknownValue(UnknownValue),
}Expand description
Option to specify the format of a Parameter resource (UNFORMATTED / YAML / JSON). This option is user specified at the time of creation of the resource and is immutable.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unspecified
The default / unset value. The API will default to the UNFORMATTED format.
Unformatted
Unformatted.
Yaml
YAML format.
Json
JSON format.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using ParameterFormat::value or ParameterFormat::name.
Implementations